@@ -1,11 +1,14 @@
 # Prompt/Timeout.pm
 #
-# Copyright (c) 2008 Serguei Trouchelle. All rights reserved.
+# $Id: Timeout.pm 1 2009-08-31 14:00:42Z stro $
+#
+# Copyright (c) 2008, 2009 Serguei Trouchelle. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
 # History:
+#  1.02  2009/08/31 Fixed problem with hanging in Unix environment, thanks to leocharre@cpan.org for reporting
 #  1.01  2008/05/23 Documentation typo
 #                   Removed Term::ReadKey::ReadMode because it doesn't work on some terminals
 #  1.00  2008/05/22 Initial revision
@@ -34,7 +37,7 @@ require Exporter;
 our @EXPORT = qw(prompt);
 our @ISA = qw(Exporter);
 
-$Prompt::Timeout::VERSION = "1.01";
+$Prompt::Timeout::VERSION = '1.02';
 
 =head1 DESCRIPTION
 
@@ -92,7 +95,7 @@ sub prompt ($;$$$) {
     while (1) {
       my $key = ReadKey(1); # 1 sec
       if (defined $key) {
-        last if $key eq "\r";
+        last if $key =~ /^[\r\n]$/x;
         $ans .= $key;
         print $key;
         $end = time + $timeout;
@@ -117,7 +120,7 @@ FindBin::Real uses partial code from ExtUtils::MakeMaker module.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008 Serguei Trouchelle. All rights reserved.
+Copyright (c) 2008, 2009 Serguei Trouchelle. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
